A module for Bài cào — a Vietnamese basic card game

```py
hand = BaiCao()         # Create a card pack
hand.shuffle_pack()     # Shuffles the pack
hand.deal()             # Deals a hand
print(hand.calculate()) # Calculates the hand's point
```